@@ -1,6 +1,7 @@
-__all__ = ('BlackListPoint',)
+__all__ = ('BlackListPoint', 'BlackListObjectPoint')
 
 from expressmoney.api import *
+from expressmoney.api.point import DestroyPointMixin
 
 SERVICE = 'loans'
 APP = 'black_list'
@@ -26,3 +27,7 @@ class BlackListPoint(ListPointMixin, CreatePointMixin, ContractPoint):
     _point_id = BlackListID()
     _read_contract = BlackListReadContract
     _create_contract = BlackListCreateContract
+
+
+class BlackListObjectPoint(DestroyPointMixin, ContractObjectPoint):
+    _point_id = BlackListID()
