@@ -1,4 +1,4 @@
-__all__ = ('ActionDescriptionPoint', 'NewUserActionPoint', 'FirstLoanActionPoint')
+__all__ = ('ActionDescriptionPoint', 'NewUserActionPoint', 'FirstLoanActionPoint', 'CreateProfileActionPoint')
 
 from expressmoney.api import *
 
@@ -8,9 +8,11 @@ APP = 'actions'
 
 class ActionDescriptionReadContract(Contract):
     NEW_USER = 'NEW_USER'
+    CREATE_PROFILE = 'CREATE_PROFILE'
     FIRST_LOAN = 'FIRST_LOAN'
     NAME_CHOICES = (
         (NEW_USER, NEW_USER),
+        (CREATE_PROFILE, CREATE_PROFILE),
         (FIRST_LOAN, FIRST_LOAN),
     )
     RU = 'RU'
@@ -31,6 +33,7 @@ class NewUserActionCreateContract(Contract):
 
 class NewUserActionReadContract(Contract):
     created = serializers.DateTimeField()
+    is_approved = serializers.BooleanField()
     referral = serializers.IntegerField(min_value=1)
     amount = serializers.DecimalField(max_digits=16, decimal_places=0)
     balance = serializers.DecimalField(max_digits=16, decimal_places=0)
@@ -45,6 +48,14 @@ class FirstLoanActionReadContract(NewUserActionReadContract):
     pass
 
 
+class CreateProfileActionCreateContract(Contract):
+    pass
+
+
+class CreateProfileActionReadContract(NewUserActionReadContract):
+    pass
+
+
 class ActionDescriptionID(ID):
     _service = SERVICE
     _app = APP
@@ -63,6 +74,12 @@ class FirstLoanActionID(ID):
     _view_set = 'first_loan_action'
 
 
+class CreateProfileActionID(ID):
+    _service = SERVICE
+    _app = APP
+    _view_set = 'create_profile_action'
+
+
 class ActionDescriptionPoint(ListPointMixin, ContractPoint):
     _point_id = ActionDescriptionID()
     _read_contract = ActionDescriptionReadContract
@@ -81,3 +98,10 @@ class FirstLoanActionPoint(ListPointMixin, CreatePointMixin, ContractPoint):
     _create_contract = FirstLoanActionCreateContract
     _read_contract = FirstLoanActionReadContract
     _sort_by = 'created'
+
+
+class CreateProfileActionPoint(ListPointMixin, CreatePointMixin, ContractPoint):
+    _point_id = CreateProfileActionID()
+    _create_contract = CreateProfileActionCreateContract
+    _read_contract = CreateProfileActionReadContract
+    _sort_by = 'created'
