@@ -1,24 +1,39 @@
 __all__ = ('IdentificationProcessPoint', 'AutoIdentificationTaskPoint')
 
 from expressmoney.api import *
-from expressmoney.viewflow import result
 
 SERVICE = 'profiles'
 
 
 class IdentificationProcessReadContract(Contract):
+    EMPTY = 'EMPTY'
+    SUCCESS = 'SCS'
+    FAILURE = 'FAIL'
+    RESULT_CHOICES = (
+        (EMPTY, EMPTY),
+        (FAILURE, FAILURE),
+        (SUCCESS, SUCCESS),
+    )
     id = serializers.IntegerField(min_value=1)
     updated = serializers.DateTimeField()
     user_id = serializers.IntegerField(min_value=1)
-    result = serializers.ChoiceField(choices=result.RESULT_CHOICES)
+    result = serializers.ChoiceField(choices=RESULT_CHOICES)
     comment = serializers.CharField(max_length=1024, allow_blank=True)
     status = serializers.CharField(max_length=50)
 
 
 class AutoIdentificationTaskReadContract(Contract):
+    EMPTY = 'EMPTY'
+    SUCCESS = 'SCS'
+    FAILURE = 'FAIL'
+    RESULT_CHOICES = (
+        (EMPTY, EMPTY),
+        (FAILURE, FAILURE),
+        (SUCCESS, SUCCESS),
+    )
     id = serializers.IntegerField(min_value=1)
     created = serializers.DateTimeField()
-    result = serializers.ChoiceField(choices=result.RESULT_CHOICES)
+    result = serializers.ChoiceField(choices=RESULT_CHOICES)
     comment = serializers.CharField(max_length=1024, allow_blank=True)
 
 
